==> additional-functions-0.1.0.tgz: package/factorials.js <==
function factorial(n){
    if(n == 0) return 1;
    else return n * factorial(n - 1);
}

function doubleFactorial(n){
    if(n == 0) return 1;
    else return n * factorial(n - 2);
}

function subfactorial(n){
    return Math.round(factorial(n) / 2.718);
}

function isprime(n){
    let result = [];
    let d = 2;
    while(d * d <= n){
        if(n % d == 0){
            result.push(d);
            n = Math.floor(n / d);
        }
        else{
            d ++;
        }
    }
    if(n > 1){
        result.push(n);
    }
    if(result.length > 1) return false;
    else return true;
}

function p(n){
    let result = [];
    let i = 0;
    let m = 1;
    let k;
    while(i < n){
        m ++;
        k = true;
        for(j of result){
            if(m % j == 0){
                k = false;
                break;
            }
        }
        if(k){
            result.push(m);
            i ++;
        }
    }
    return result[result.length - 1];
}

function primorial(n){
    if(n == 1) return 1;
    else if(isprime(n)) return n * primorial(n - 1);
    else return primorial(n - 1);
}

function pPrimorial(n){
    return primorial(p(n));
}

function superfactorial(n){
    if(n == 0) return 1;
    else return factorial(n) * superfactorial(n - 1);
}

function superduperfactorial(n){
    if(n == 0) return 1;
    else return superfactorial(n) * superduperfactorial(n - 1);
}

module.exports = {factorial, doubleFactorial, subfactorial, primorial, pPrimorial, superfactorial, superduperfactorial};

==> additional-functions-0.13.0.tgz: package/factorials.js <==
function factorial(n){
    if(n == 0) return 1;
    else return n * factorial(n - 1);
}

function doubleFactorial(n){
    if(n == 0) return 1;
    else return n * doubleFactorial(n - 2);
}

function subfactorial(n){
    return Math.round(factorial(n) / 2.718);
}

function isprime(n){
    let result = [];
    let d = 2;
    while(d * d <= n){
        if(n % d == 0){
            result.push(d);
            n = Math.floor(n / d);
        }
        else{
            d ++;
        }
    }
    if(n > 1){
        result.push(n);
    }
    if(result.length > 1) return false;
    else return true;
}

function p(n){
    let result = [];
    let i = 0;
    let m = 1;
    let k;
    while(i < n){
        m ++;
        k = true;
        for(j of result){
            if(m % j == 0){
                k = false;
                break;
            }
        }
        if(k){
            result.push(m);
            i ++;
        }
    }
    return result[result.length - 1];
}

function primorial(n){
    if(n == 1) return 1;
    else if(isprime(n)) return n * primorial(n - 1);
    else return primorial(n - 1);
}

function pPrimorial(n){
    return primorial(p(n));
}

function superfactorial(n){
    if(n == 0) return 1;
    else return factorial(n) * superfactorial(n - 1);
}

function superduperfactorial(n){
    if(n == 0) return 1;
    else return superfactorial(n) * superduperfactorial(n - 1);
}

module.exports = {factorial, doubleFactorial, subfactorial, primorial, pPrimorial, superfactorial, superduperfactorial};
